--[[
Import libraries, other files.
Save, load data.
Return translation.

DToX, 2014
Licensed under the same terms as Lua itself.
--]]





-- import "Turbine";
-- import "Turbine.UI";
import "Turbine.UI.Lotro";
import "Turbine.Gameplay";


-- Custom library. Start
--
import( "DToX.Vitals.lib.index" );
local _Lib = DToX.Vitals.lib._Lib;

_Lib.path = "DToX.Vitals.lib."; -- For load function
_Lib.pName = "Vitals"; -- For wl in lib file

fonts, colors, align = _Lib.fonts, _Lib.colors, _Lib.align;
getBorders = _Lib.getBorders;
onScreen = _Lib.onScreen;
-- Measure
Text = _Lib.load( "Text" );
-- Chat. Functions: dumpValues, writeLine
_Lib.load( "Chat" );
wl, dv = _Lib.Chat.writeLine, _Lib.Chat.dumpValues;
-- Plugin. Functions: convertData, language/lang, loadData, saveData
Plugin = _Lib.load( "Plugin" );
-- Visual ones
Hint = _Lib.load( "Hint" ); -- Functions: show, remove
-- Hint.TextWidth = "Single";
--
-- Custom library. End





-- Variables and constants
--
local P_DATA_NAME = "M_Vitals";
local P_DATA_SCOPE = "Character";

local T_defaultLangCode = "ENG";
local T_langCode;
local T_transMap;

-- Forward declarations
--
Vitals = {};
Vitals.Settings = {};
Vitals.Translation = {};





-- Functions
--

local ts = tostring;

-- Returns translation. Or defaults to english, if language file is missing
function T( transCode, bUpdate )
   if ( bUpdate or not T_langCode ) then
      T_langCode = Vitals.Settings.Language;
      T_transMap = Vitals.Translation[T_langCode];
      if ( not T_transMap ) then
         T_transMap = Vitals.Translation[T_defaultLangCode];
      end
   end

   return T_transMap[transCode];
end

function saveData( dataName )
   local dataName = dataName or P_DATA_NAME;
   local data = {};

   -- Get common settings
   data.Language = Vitals.Settings.Language;
   data.Font = Vitals.Settings.Bar.Font;
   data.FontNamebar = Vitals.Settings.Bar.FontNameBar;

   -- Get windows' positions
   for i, obj in pairs( Vitals.Object ) do
      local si = ts( i );
      local x, y = obj:GetPosition();
      data[si] = x .. ";" .. y;
   end

   Plugin.saveData( P_DATA_SCOPE, dataName, data );
end

local function loadData( dataName )
   local dataName = dataName or P_DATA_NAME;

   return Plugin.loadData( P_DATA_SCOPE, dataName );
end





-- Logic
--

-- Determine language
Vitals.Settings.Language = Plugin.lang();

-- Load plugin's translations
import "DToX.Vitals.Translation.ENG";
pcall( import, "DToX.Vitals.Translation.FRE" );
pcall( import, "DToX.Vitals.Translation.GER" );
import "DToX.Vitals.Translation.RUS";

-- Load plugin's core
import "DToX.Vitals.Vitals_TargetVisuals";
import "DToX.Vitals.Vitals_Target";

-- Load saved data
local savedData = loadData();

if ( savedData ) then
   Vitals.Settings.Language = savedData.Language;
   Vitals.Settings.Bar.Font = savedData.Font;
   Vitals.Settings.Bar.FontNameBar = savedData.FontNamebar;

   local pos = {}; -- 1 = x, 2 = y
   local i = 1;
   local si = ts( i );
   while ( savedData[si] ) do
      -- Add new target
      Vitals();

      -- Get saved position
      local j = 0;
      for posValue in string.gmatch( savedData[si], "%d+" ) do
         j = j + 1;
         pos[j] = posValue;
      end

      -- Set and check position
      Vitals.Object[i]:SetPosition( pos[1], pos[2] );
      onScreen( Vitals.Object[i] );
      
      i = i + 1;
      si = ts( i );
   end

else
   -- Add first target
   Vitals();
end
